- smoothing.methods
A character giving the smoothing method
for the chosen smooth. The two possibilites are (i) "direct", for directly
smoothing the observed response, and (ii) "logarithmic", for
smoothing the log-transformed response.
- spline.types
A character giving the type of spline
for the chosen smooth. Currently, the possibilites are (i) "NCSS", for natural
cubic smoothing splines, and (ii) "PS", for P-splines.
- df
A numeric with single value that specifies, for
natural cubic smoothing splines (NCSS), the desired equivalent
numbers of degrees of freedom of the chosen smooth (trace of the smoother matrix).
Lower values result in more smoothing.
- lambdas
A named list or a numeric specifying
the single positive value of the penalty for which the chosen smooth is required.
- combinations
Generally, this argument should be set to single so that
only one value should be supplied to the functions arguments. Also, only one of
df or lambdas should be set.
- ...
allows arguments to be passed to other functions; not used at present.