| byIndv4Times_WaterUse | R Documentation |
data.frame, water use traits calculated for consecutive times
for individuals in the data.frame in long format.Calculates, for subsets of the data, those water traits out of
Water Use (WU), Water Use Rate (WUR) and Water Use Index (WUI) that are
specified in which.water.traits. The traits are calculated
continuously over time for the water traits using the values of
the variables for consecutive times stored in data.
The weight.after column and whichever of weight.before
and water.added is not NULL are used in the calculations.
The subsets are those values with the same levels combinations of the
factors listed in individuals.
If avail.time.diffs is FALSE, the differences between
consecutive time values are calculated for each value of
individuals.
byIndv4Times_WaterUse(data, weight.after = "Weight.After",
weight.before = NULL, water.added = NULL,
responseAGR = NULL,
individuals = "Snapshot.ID.Tag", times = "DAP",
which.trait.types = c("WU","WUR","WUI"),
water.trait.names = c("WU", "WUR", "WUI"),
avail.times.diffs = FALSE, ntimes2span = 2)
data |
A |
weight.after |
A |
weight.before |
A |
water.added |
A |
responseAGR |
A |
individuals |
A |
times |
A |
which.trait.types |
A |
water.trait.names |
A |
avail.times.diffs |
A |
ntimes2span |
A |
If weight.before is not NULL, then the water use (WU)
between consecutive times is calulated as value of
weight.after for first time minus the weight.after for
the second time. If water.added is not NULL, then the
water use (WU) between consecutive times is calulated as value
of the water.added minus the the difference between the
weight.after values for the two consecutive times.
The WUR is calculated as the WU divided by the
times.diffs and the WUI is calculated as the ratio of
the values on the column nomiated by responseAGR to the
WUR values.
A data.frame containing data to which has been
added i) a column for the differences between the times,
if it is not already in data, and (ii) columns with the water
traits nominated in which.trait.types using the names specified in
water.trait.names. The name of the column for times
differences will be the value of times with ".diffs"
appended. Each water trait will be positioned at observation
ceiling(ntimes2span + 1) / 2 relative to the two times from
which the growth rate is calculated.
Chris Brien
smoothSpline, byIndv4Times_GRsDiff
data(exampleData)
longi.dat <- byIndv4Times_WaterUse(data = longi.dat,
weight.before = "Weight.Before",
individuals = "Snapshot.ID.Tag",
times = "DAP",
which.trait.types = c("WU","WUR","WUI"),
water.trait.names = c("WU", "WUR","WUI"),
responseAGR = "PSA.AGR")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.